==> haskell-sandi-0.4.2-56-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-sandi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: sandi
version: 0.4.2
id: sandi-0.4.2-EOP80oadUWcG9rUm9zt8Jr
key: sandi-0.4.2-EOP80oadUWcG9rUm9zt8Jr
license: BSD-3-Clause
copyright: Magnus Therning, 2012
maintainer: magnus@therning.org
author: Magnus Therning
homepage: http://hackage.haskell.org/package/sandi
synopsis: Data encoding library
description:
    Reasonably fast data encoding library.
category: Codec, Conduit
abi: c9cbbe719607654255f4fcb6dcd02469
exposed: True
exposed-modules:
    Codec.Binary.Base16 Codec.Binary.Base32 Codec.Binary.Base32Hex
    Codec.Binary.Base64 Codec.Binary.Base64Url Codec.Binary.Base85
    Codec.Binary.QuotedPrintable Codec.Binary.Uu Codec.Binary.Xx
    Codec.Binary.Yenc Data.Conduit.Codec.Base16
    Data.Conduit.Codec.Base32 Data.Conduit.Codec.Base32Hex
    Data.Conduit.Codec.Base64 Data.Conduit.Codec.Base64Url
    Data.Conduit.Codec.Base85 Data.Conduit.Codec.QuotedPrintable
    Data.Conduit.Codec.Uu Data.Conduit.Codec.Xx Data.Conduit.Codec.Yenc
hidden-modules: Data.Conduit.Codec.Util
import-dirs: /usr/lib/ghc-8.4.3/site-local/sandi-0.4.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/sandi-0.4.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/sandi-0.4.2
hs-libraries: HSsandi-0.4.2-EOP80oadUWcG9rUm9zt8Jr
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    stringsearch-0.3.6.6-LoTdLPC2CyELyKPpIlHZHq
    conduit-1.3.0.3-2pJCSncQS97DBjtJl8NaxW
    exceptions-0.10.0-IRO0p79DXGKGDsbbDc50a8
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             stringsearch-0.3.6.6-LoTdLPC2CyELyKPpIlHZHq=e8c1944b7c8b87b6021bfbe6be250d99
             conduit-1.3.0.3-2pJCSncQS97DBjtJl8NaxW=a0efd684e93e35619771d8ef5ca6ca30
             exceptions-0.10.0-IRO0p79DXGKGDsbbDc50a8=e9779fb859fee3584d68df46d12eac41
haddock-interfaces: /usr/share/doc/haskell-sandi/html/sandi.haddock
haddock-html: /usr/share/doc/haskell-sandi/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-sandi-0.4.2-60-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-sandi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: sandi
version: 0.4.2
id: sandi-0.4.2-2T18lubZoS6E8YWfXvx96I
key: sandi-0.4.2-2T18lubZoS6E8YWfXvx96I
license: BSD-3-Clause
copyright: Magnus Therning, 2012
maintainer: magnus@therning.org
author: Magnus Therning
homepage: http://hackage.haskell.org/package/sandi
synopsis: Data encoding library
description:
    Reasonably fast data encoding library.
category: Codec, Conduit
abi: 9ed0957357fa01f9fc5ef3927de4e082
exposed: True
exposed-modules:
    Codec.Binary.Base16 Codec.Binary.Base32 Codec.Binary.Base32Hex
    Codec.Binary.Base64 Codec.Binary.Base64Url Codec.Binary.Base85
    Codec.Binary.QuotedPrintable Codec.Binary.Uu Codec.Binary.Xx
    Codec.Binary.Yenc Data.Conduit.Codec.Base16
    Data.Conduit.Codec.Base32 Data.Conduit.Codec.Base32Hex
    Data.Conduit.Codec.Base64 Data.Conduit.Codec.Base64Url
    Data.Conduit.Codec.Base85 Data.Conduit.Codec.QuotedPrintable
    Data.Conduit.Codec.Uu Data.Conduit.Codec.Xx Data.Conduit.Codec.Yenc
hidden-modules: Data.Conduit.Codec.Util
import-dirs: /usr/lib/ghc-8.4.3/site-local/sandi-0.4.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/sandi-0.4.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/sandi-0.4.2
hs-libraries: HSsandi-0.4.2-2T18lubZoS6E8YWfXvx96I
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    stringsearch-0.3.6.6-LoTdLPC2CyELyKPpIlHZHq
    conduit-1.3.1-JR2jMm57F9p4PvlZ0CCgmp
    exceptions-0.10.0-IRO0p79DXGKGDsbbDc50a8
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             stringsearch-0.3.6.6-LoTdLPC2CyELyKPpIlHZHq=e8c1944b7c8b87b6021bfbe6be250d99
             conduit-1.3.1-JR2jMm57F9p4PvlZ0CCgmp=16734a62a84599c1bebef0162694b893
             exceptions-0.10.0-IRO0p79DXGKGDsbbDc50a8=e9779fb859fee3584d68df46d12eac41
haddock-interfaces: /usr/share/doc/haskell-sandi/html/sandi.haddock
haddock-html: /usr/share/doc/haskell-sandi/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
